@@ -111,6 +111,5 @@ gridparameters(meuse.grid)
 
 data(meuse.grid_ll)
 try(gridded(meuse.grid_ll) <- TRUE)
-try(meuse.grid_ll <- SpatialPixelsDataFrame(as(meuse.grid_ll, "SpatialPoints"), data=as(meuse.grid_ll, "data.frame"), tolerance=0.9, fuzz.tol=2))
+try(meuse.grid_ll <- SpatialPixelsDataFrame(as(meuse.grid_ll, "SpatialPoints"), data=as(meuse.grid_ll, "data.frame"), tolerance=0.9))
 gridparameters(meuse.grid_ll)
-
